"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OptionsCheck = void 0;

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _immutable = require("immutable");

var _reactUid = require("react-uid");

var _LocaleHelperText = require("../../Component/LocaleHelperText/LocaleHelperText");

var CheckInput = function CheckInput(_ref) {
  var currentValue = _ref.currentValue,
      onChange = _ref.onChange,
      label = _ref.label,
      value = _ref.value,
      classForm = _ref.classForm,
      classLabel = _ref.classLabel,
      classFormControl = _ref.classFormControl;
  var uid = (0, _reactUid.useUID)();
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: classForm
  }, /*#__PURE__*/_react["default"].createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: currentValue,
    onChange: onChange
  }), /*#__PURE__*/_react["default"].createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

var OptionsCheckValue = (0, _uiSchema.extractValue)((0, _uiSchema.memo)(function (_ref2) {
  var enumVal = _ref2.enumVal,
      storeKeys = _ref2.storeKeys,
      value = _ref2.value,
      _onChange = _ref2.onChange,
      classLabel = _ref2.classLabel,
      classFormControl = _ref2.classFormControl,
      classForm = _ref2.classForm,
      schema = _ref2.schema,
      required = _ref2.required,
      type = _ref2.type;
  return enumVal ? enumVal.map(function (enum_name) {
    var currentValue = value && value.contains && typeof value.contains(enum_name) !== 'undefined' ? value.contains(enum_name) : false;
    return /*#__PURE__*/_react["default"].createElement(CheckInput, {
      key: enum_name,
      value: enum_name,
      classForm: classForm,
      classLabel: classLabel,
      classFormControl: classFormControl,
      currentValue: currentValue,
      onChange: function onChange() {
        if (currentValue) {
          _onChange((0, _uiSchema.updateValue)(storeKeys, value["delete"](value.indexOf(enum_name)), required, type));
        } else {
          _onChange((0, _uiSchema.updateValue)(storeKeys, value ? value.push(enum_name) : (0, _immutable.List)([]).push(enum_name), required, type));
        }
      },
      label: /*#__PURE__*/_react["default"].createElement(_uiSchema.Trans, {
        schema: schema.get('t'),
        text: storeKeys.insert(0, 'widget').concat((0, _immutable.List)(['enum', enum_name])).join('.'),
        context: (0, _immutable.Map)({
          'relative': (0, _immutable.List)(['enum', enum_name])
        }),
        fallback: (0, _uiSchema.beautifyKey)(enum_name)
      })
    });
  }).valueSeq() : null;
}));

var OptionsCheck = function OptionsCheck(_ref3) {
  var schema = _ref3.schema,
      storeKeys = _ref3.storeKeys,
      showValidity = _ref3.showValidity,
      errors = _ref3.errors,
      ownKey = _ref3.ownKey,
      required = _ref3.required;
  var enumVal = schema.get('enum');
  if (!enumVal) return null;
  var classForm = ["custom-control", "custom-checkbox"];
  var classLabel = ["custom-control-label", "text-light"];
  var classFormControl = ["custom-control-input", "checkbox-inline"];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_uiSchema.TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/_react["default"].createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    enumVal: enumVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/_react["default"].createElement(_LocaleHelperText.ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

exports.OptionsCheck = OptionsCheck;