"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TextRenderer = exports.NumberRenderer = exports.StringRenderer = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _uiSchema = require("@ui-schema/ui-schema");

var _LocaleHelperText = require("../../Component/LocaleHelperText/LocaleHelperText");

var _reactUid = require("react-uid");

var StringRenderer = function StringRenderer(_ref) {
  var ownKey = _ref.ownKey,
      schema = _ref.schema,
      value = _ref.value,
      _ref$multiline = _ref.multiline,
      multiline = _ref$multiline === void 0 ? false : _ref$multiline,
      _onChange = _ref.onChange,
      storeKeys = _ref.storeKeys,
      showValidity = _ref.showValidity,
      required = _ref.required,
      errors = _ref.errors,
      type = _ref.type,
      rows = _ref.rows;
  var format = schema.get('format');
  var uid = (0, _reactUid.useUID)();
  var Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  var classFormGroup = ["form-group"];
  var classFormControl = ["form-control"];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classFormGroup.push('was-validated');
  }

  return /*#__PURE__*/_react["default"].createElement("div", {
    className: classFormGroup.join(' ')
  }, /*#__PURE__*/_react["default"].createElement("label", {
    htmlFor: 'uis-' + uid
  }, /*#__PURE__*/_react["default"].createElement(_uiSchema.TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  })), /*#__PURE__*/_react["default"].createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: function onChange(e) {
      var value = e.target.value;
      var target = e.target;

      if (type === 'number') {
        if (isNaN(value * 1)) {
          console.error('Invalid Type: input not a number in:', target);
          return;
        }

        _onChange((0, _uiSchema.updateValue)(storeKeys, value === '' ? '' : value * 1, required, type || schema.get('type')));
      } else {
        _onChange((0, _uiSchema.updateValue)(storeKeys, value, required, type || schema.get('type')));
      }
    }
  }), /*#__PURE__*/_react["default"].createElement(_LocaleHelperText.ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

exports.StringRenderer = StringRenderer;

var TextRenderer = function TextRenderer(_ref2) {
  var schema = _ref2.schema,
      props = (0, _objectWithoutProperties2["default"])(_ref2, ["schema"]);
  return /*#__PURE__*/_react["default"].createElement(StringRenderer, (0, _extends2["default"])({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

exports.TextRenderer = TextRenderer;

var NumberRenderer = function NumberRenderer(_ref3) {
  var schema = _ref3.schema,
      props = (0, _objectWithoutProperties2["default"])(_ref3, ["schema"]);
  return /*#__PURE__*/_react["default"].createElement(StringRenderer, (0, _extends2["default"])({}, props, {
    schema: schema,
    type: 'number'
  }));
};

exports.NumberRenderer = NumberRenderer;